==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Massstäbe und Bildlaufleisten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Massstäbe anzeigen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Zeiger</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Raster</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Raster automatisch skalieren</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Durchgezogene Rasterlinien</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Minimaler Rasterabstand (pix):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Metaraster automatisch skalieren</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Grosse Ursprungsachsen anzeigen</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Auto Ansicht</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Randabstand (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto Ansicht nach Laden</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Farbanpassung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Farbgrenzwert:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Linientypen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automatisch Bildschirmbasierte Linientypen verwenden in Modellansicht</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Linienmuster skalieren basierend auf Linienbreite</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Linientypskalierung für Linienstärke 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Anzeige und Leistung</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Gestrichelte Objekte mit mehr als N Strichen ausgezogen darstellen:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimaler Winkel für Bogensegmentierung in Anzeige (Grad):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Volle Auflösung benutzen für Retina-Display</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Kantenglättung standardmässig an</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximale Anzahl angezeigte Referenzpunkte:</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Timeout für Schraffurwiedergabe:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Kantenglättung standardmässig an</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Gestrichelte Objekte mit mehr als N Strichen ausgezogen darstellen:</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automatisch Bildschirmbasierte Linientypen verwenden in Modellansicht</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Linientypen automatisch umschalten</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Leistung</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Anzahl Vorschau Objekte:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Anzeigegrenzwert für Texte (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Bögen als Linien anzeigen falls Winkel kleiner als (Grad):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Anzeigegrenzwert für Texte:</translation>
    </message>
    <message>
        <location line="+339"/>
        <source>Selection</source>
        <translation>Selektion</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Persistente Selektion</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Massstäbe anzeigen</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translation type="obsolete">Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation type="obsolete">Zeiger</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translation type="obsolete">Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Raster</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Durchgezogene Rasterlinien</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Minimaler Rasterabstand (pix):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Auto Ansicht</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Farbanpassung</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Farbgrenzwert:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Leistung</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Anzeigegrenzwert für Texte:</translation>
    </message>
    <message>
        <source>5</source>
        <translation type="obsolete">5</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <source>15</source>
        <translation type="obsolete">15</translation>
    </message>
    <message>
        <source>20</source>
        <translation type="obsolete">20</translation>
    </message>
    <message>
        <source>25</source>
        <translation type="obsolete">25</translation>
    </message>
    <message>
        <source>50</source>
        <translation type="obsolete">50</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translation type="obsolete">Randabstand (px):</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <source>100</source>
        <translation type="obsolete">100</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Vorschau</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Anzahl Vorschau Objekte:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="obsolete">Objekte</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translation type="obsolete">Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selektion</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translation type="obsolete">Persistente Selektion</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Raster automatisch skalieren</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translation type="obsolete">Massstäbe und Bildlaufleisten</translation>
    </message>
    <message>
        <source>Show cross hairs</source>
        <translation type="obsolete">Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <source>Show large cross hairs</source>
        <translation type="obsolete">Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Erscheinung</translation>
    </message>
    <message>
        <source>30</source>
        <translation type="obsolete">30</translation>
    </message>
    <message>
        <source>250</source>
        <translation type="obsolete">250</translation>
    </message>
    <message>
        <source>500</source>
        <translation type="obsolete">500</translation>
    </message>
    <message>
        <source>1000</source>
        <translation type="obsolete">1000</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Massstäbe und Bildlaufleisten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Massstäbe anzeigen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Zeiger</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Raster</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Raster automatisch skalieren</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Durchgezogene Rasterlinien</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Minimaler Rasterabstand (pix):</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Metaraster automatisch skalieren</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Ursprung</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Grosse Ursprungsachsen anzeigen</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Auto Ansicht</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Randabstand (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto Ansicht nach Laden</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Farbanpassung</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Farbgrenzwert:</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation>Beim Drucken deaktivieren</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Linientypen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automatisch Bildschirmbasierte Linientypen verwenden in Modellansicht</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Linienmuster skalieren basierend auf Linienbreite</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Linientypskalierung für Linienstärke 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Anzeige und Leistung</translation>
    </message>
    <message>
        <location line="+229"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Gestrichelte Objekte mit mehr als N Strichen ausgezogen darstellen:</translation>
    </message>
    <message>
        <location line="-82"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimaler Winkel für Bogensegmentierung in Anzeige (Grad):</translation>
    </message>
    <message>
        <location line="-134"/>
        <source>Use full resolution for Retina display</source>
        <translation>Volle Auflösung benutzen für Retina-Display</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Kantenglättung standardmässig an</translation>
    </message>
    <message>
        <location line="+327"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximale Anzahl angezeigte Referenzpunkte:</translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Timeout für Schraffurwiedergabe:</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Kantenglättung standardmässig an</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Gestrichelte Objekte mit mehr als N Strichen ausgezogen darstellen:</translation>
    </message>
    <message>
        <location line="-343"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automatisch Bildschirmbasierte Linientypen verwenden in Modellansicht</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Linientypen automatisch umschalten</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Leistung</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Number of preview entities:</source>
        <translation>Anzahl Vorschau Objekte:</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Anzeigegrenzwert für Texte (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Bögen als Linien anzeigen falls Winkel kleiner als (Grad):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Anzeigegrenzwert für Texte:</translation>
    </message>
    <message>
        <location line="+335"/>
        <source>Selection</source>
        <translation>Selektion</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Persistente Selektion</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Massstäbe anzeigen</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translation type="obsolete">Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Bildlaufleisten anzeigen</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation type="obsolete">Zeiger</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translation type="obsolete">Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Raster</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Durchgezogene Rasterlinien</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Minimaler Rasterabstand (pix):</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Auto Ansicht</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Farbanpassung</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Farbgrenzwert:</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Leistung</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Anzeigegrenzwert für Texte:</translation>
    </message>
    <message>
        <source>5</source>
        <translation type="obsolete">5</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <source>15</source>
        <translation type="obsolete">15</translation>
    </message>
    <message>
        <source>20</source>
        <translation type="obsolete">20</translation>
    </message>
    <message>
        <source>25</source>
        <translation type="obsolete">25</translation>
    </message>
    <message>
        <source>50</source>
        <translation type="obsolete">50</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translation type="obsolete">Randabstand (px):</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <source>100</source>
        <translation type="obsolete">100</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Vorschau</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Anzahl Vorschau Objekte:</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="obsolete">Objekte</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translation type="obsolete">Schwarz / weiss automatisch anpassen</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Selektion</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translation type="obsolete">Persistente Selektion</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Raster automatisch skalieren</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translation type="obsolete">Massstäbe und Bildlaufleisten</translation>
    </message>
    <message>
        <source>Show cross hairs</source>
        <translation type="obsolete">Fadenkreuz anzeigen</translation>
    </message>
    <message>
        <source>Show large cross hairs</source>
        <translation type="obsolete">Grosses Fadenkreuz</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafikansicht</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Erscheinung</translation>
    </message>
    <message>
        <source>30</source>
        <translation type="obsolete">30</translation>
    </message>
    <message>
        <source>250</source>
        <translation type="obsolete">250</translation>
    </message>
    <message>
        <source>500</source>
        <translation type="obsolete">500</translation>
    </message>
    <message>
        <source>1000</source>
        <translation type="obsolete">1000</translation>
    </message>
</context>
</TS>
